Documentation
¶
Index ¶
- type EvaluationEngine
- type Evaluator
- func (t *Evaluator) Evaluate(file string) (any, error)
- func (t *Evaluator) EvaluateJson(file string) (string, error)
- func (t *Evaluator) EvaluateJsonMulti(file string) (map[string]string, error)
- func (t *Evaluator) EvaluateJsonMultiIter(file string) (iter.Seq2[FileOutput, error], error)
- func (t *Evaluator) EvaluateYaml(file string) (string, error)
- func (t *Evaluator) EvaluateYamlMulti(file string) (map[string]string, error)
- func (t *Evaluator) EvaluateYamlMultiIter(file string) (iter.Seq2[FileOutput, error], error)
- func (t *Evaluator) ExtCode(key, val string)
- func (t *Evaluator) ExtVar(key, val string)
- func (t *Evaluator) JPaths(paths []string)
- func (t *Evaluator) TraceOut(w io.Writer)
- type FileOutput
- type NativeFunction
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EvaluationEngine ¶
type Evaluator ¶
type Evaluator struct {
// contains filtered or unexported fields
}
func NewEvaluator ¶
func NewEvaluator() *Evaluator
func (*Evaluator) EvaluateJsonMulti ¶
func (*Evaluator) EvaluateJsonMultiIter ¶ added in v0.1.1
The caller MUST range over the returned iterator to execute the manifestation and release underlying evaluation resources back to the pool.
func (*Evaluator) EvaluateYamlMulti ¶
func (*Evaluator) EvaluateYamlMultiIter ¶ added in v0.1.1
The caller MUST range over the returned iterator to execute the manifestation and release underlying evaluation resources back to the pool.
type FileOutput ¶ added in v0.1.1
Click to show internal directories.
Click to hide internal directories.